// file: relay_request.cpp
//
// Change the state of an individual relay.
//
// compile with:
//  $ gcc -o relay_request relay_request.cpp -llcm
//
// On a system with pkg-config, you can also use:
//  $ gcc -o relay_request relay_request.cpp `pkg-config --cflags --libs lcm`

#include <stdio.h>
#include <iostream>

#include <lcm/lcm-cpp.hpp>
#include "dataspeed_pds_lcm/relay_request_t.hpp"

using namespace std;

int main(int argc, char** argv)
{
    if (argc < 3) {
        cout << "Usage: relay_request channel# [on|off|toggle]" << endl;
        return 1;
    }

    int channel = atoi(argv[1]);
    string mode = argv[2];

    if (channel < 0 || channel > 51) {
        cout << "Channel number must be between 0 and 51." << endl;
        return 1;
    }

    if (mode.compare("on") && mode.compare("off") && mode.compare("toggle")) {
        cout << "Request must be on, off, or toggle." << endl;
        return 1;
    }

    lcm::LCM lcm("udpm://225.0.0.0:7667?ttl=1");

    if(!lcm.good())
        return 1;

    dataspeed_pds_lcm::relay_request_t relay_msg;
    relay_msg.channel = channel;
    if (mode.compare("off") == 0) {
        relay_msg.request = 0;
    } else if (mode.compare("on") == 0) {
        relay_msg.request = 1;
    } else if (mode.compare("toggle") == 0) {
        relay_msg.request = 2;
    }
    lcm.publish("RELAY", &relay_msg);

    return 0;
}
