// file: script_request.cpp
//
// Change the state of an individual relay.
//
// compile with:
//  $ gcc -o script_request script_request.cpp -llcm
//
// On a system with pkg-config, you can also use:
//  $ gcc -o script_request script_request.cpp `pkg-config --cflags --libs lcm`

#include <stdio.h>
#include <iostream>

#include <lcm/lcm-cpp.hpp>
#include "dataspeed_pds_lcm/script_request_t.hpp"

using namespace std;

int main(int argc, char** argv)
{
    if (argc < 2) {
        cout << "Usage: script_request {stop|startup|shutdown}" << endl;
        return 1;
    }

    string script = argv[1];

    if (script.compare("stop") && script.compare("startup") && script.compare("shutdown")) {
        cout << "Request must be stop, startup, or shutdown." << endl;
        return 1;
    }

    lcm::LCM lcm("udpm://225.0.0.0:7667?ttl=1");

    if(!lcm.good())
        return 1;

    dataspeed_pds_lcm::script_request_t script_msg;
    if (script.compare("stop") == 0) {
        script_msg.script = 0;
    } else if (script.compare("startup") == 0) {
        script_msg.script = 1;
    } else if (script.compare("shutdown") == 0) {
        script_msg.script = 2;
    }
    lcm.publish("SCRIPT", &script_msg);

    return 0;
}
