// file: set_mode.cpp
//
// Changes the mode of the power distribution system.
//
// compile with:
//  $ gcc -o set_mode set_mode.cpp -llcm
//
// On a system with pkg-config, you can also use:
//  $ gcc -o set_mode set_mode.cpp `pkg-config --cflags --libs lcm`

#include <stdio.h>
#include <iostream>

#include <lcm/lcm-cpp.hpp>
#include "dataspeed_pds_lcm/mode_t.hpp"

using namespace std;

int main(int argc, char** argv)
{
    if (argc < 2) {
        cout << "Usage: set_mode [auto|manual|valet]" << endl;
        return 1;
    }

    string mode = argv[1];

    if (mode.compare("auto") && mode.compare("manual") && mode.compare("valet")) {
        cout << "Mode must be auto, manual, or valet." << endl;
        return 1;
    }

    lcm::LCM lcm("udpm://225.0.0.0:7667?ttl=1");

    if(!lcm.good())
        return 1;

    dataspeed_pds_lcm::mode_t mode_msg;
    if (mode.compare("auto") == 0) {
        mode_msg.mode = 0;
    } else if (mode.compare("manual") == 0) {
        mode_msg.mode = 1;
    } else if (mode.compare("valet") == 0) {
        mode_msg.mode = 2;
    }
    lcm.publish("MODE", &mode_msg);

    return 0;
}
